@@ -1,4 +1,4 @@
-/* Copyright (c) 2002,2003,2005,2006, Marek Michalkiewicz, Joerg Wunsch
+/* Copyright (c) 2002,2003,2005,2006,2007 Marek Michalkiewicz, Joerg Wunsch
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,8 +28,9 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io.h,v 1.24.2.7 2006/04/19 16:53:25 aesok Exp $ */
+/* $Id: io.h,v 1.24.2.17 2007/05/13 20:36:03 aesok Exp $ */
 
+/** \file */
 /** \defgroup avr_io <avr/io.h>: AVR device-specific IO definitions
     \code #include <avr/io.h> \endcode
 
@@ -166,6 +167,11 @@
 #define    EEWE         1
 #define    EERE         0
 
+/* Extended indirect addressing of ATmega256x devices */
+#if __AVR_ARCH__ == 6
+#  define EIND     _SFR_IO8(0X3C)
+#endif
+
 #endif /* __COMPILING_AVR_LIBC__ */
 
 #if defined (__AVR_AT94K__)
@@ -178,6 +184,8 @@
 #  include <avr/io76c711.h>
 #elif defined (__AVR_AT86RF401__)
 #  include <avr/io86r401.h>
+#elif defined (__AVR_AT90PWM1__)
+#  include <avr/io90pwm1.h>
 #elif defined (__AVR_AT90PWM2__)
 #  include <avr/io90pwmx.h>
 #elif defined (__AVR_AT90PWM3__)
@@ -188,12 +196,20 @@
 #  include <avr/iom1280.h>
 #elif defined (__AVR_ATmega1281__)
 #  include <avr/iom1281.h>
+#elif defined (__AVR_ATmega2560__)
+#  include <avr/iom2560.h>
+#elif defined (__AVR_ATmega2561__)
+#  include <avr/iom2561.h>
 #elif defined (__AVR_AT90CAN32__)
 #  include <avr/iocan32.h>
 #elif defined (__AVR_AT90CAN64__)
 #  include <avr/iocan64.h>
 #elif defined (__AVR_AT90CAN128__)
 #  include <avr/iocan128.h>
+#elif defined (__AVR_AT90USB82__)
+#  include <avr/iousb82.h>
+#elif defined (__AVR_AT90USB162__)
+#  include <avr/iousb162.h>
 #elif defined (__AVR_AT90USB646__)
 #  include <avr/iousb646.h>
 #elif defined (__AVR_AT90USB647__)
@@ -228,12 +244,20 @@
 #  include <avr/iom324.h>
 #elif defined (__AVR_ATmega325__)
 #  include <avr/iom325.h>
+#elif defined (__AVR_ATmega325P__)
+#  include <avr/iom325.h>
 #elif defined (__AVR_ATmega3250__)
 #  include <avr/iom3250.h>
+#elif defined (__AVR_ATmega3250P__)
+#  include <avr/iom3250.h>
 #elif defined (__AVR_ATmega329__)
 #  include <avr/iom329.h>
+#elif defined (__AVR_ATmega329P__)
+#  include <avr/iom329.h>
 #elif defined (__AVR_ATmega3290__)
 #  include <avr/iom3290.h>
+#elif defined (__AVR_ATmega3290P__)
+#  include <avr/iom3290.h>
 #elif defined (__AVR_ATmega406__)
 #  include <avr/iom406.h>
 #elif defined (__AVR_ATmega16__)
@@ -248,10 +272,18 @@
 #  include <avr/iom164.h>
 #elif defined (__AVR_ATmega165__)
 #  include <avr/iom165.h>
+#elif defined (__AVR_ATmega165P__)
+#  include <avr/iom165p.h>
 #elif defined (__AVR_ATmega168__)
 #  include <avr/iom168.h>
 #elif defined (__AVR_ATmega169__)
 #  include <avr/iom169.h>
+#elif defined (__AVR_ATmega169P__)
+#  include <avr/iom169p.h>
+#elif defined (__AVR_ATmega8HVA__)
+#  include <avr/iom8hva.h>
+#elif defined (__AVR_ATmega16HVA__)
+#  include <avr/iom16hva.h>
 #elif defined (__AVR_ATmega8__)
 #  include <avr/iom8.h>
 #elif defined (__AVR_ATmega48__)
