@@ -1,4 +1,4 @@
-/* Copyright (c) 2004,2005, Colin O'Flynn <coflynn@newae.com>
+/* Copyright (c) 2004,2005,2006 Colin O'Flynn <coflynn@newae.com>
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iocanxx.h,v 1.1 2005/10/25 19:44:25 aesok Exp $ */
+/* $Id: iocanxx.h,v 1.1.2.4 2007/01/22 23:27:45 joerg_wunsch Exp $ */
 
 /* This file is based largely on:
    - iom128.h by Peter Jansen (bit defines)
@@ -390,9 +390,12 @@
 #define CANIE1 _SFR_MEM8(0xDF)
 
 /* RegDef:  CAN Status Interrupt MOb Register*/
+/*
+ * WARNING: Do not apply the SIT8...SIT14 constants to bits in the CANSIT
+ * register.
+ */
+#define CANSIT  _SFR_MEM16(0xE0)
 #define CANSIT2 _SFR_MEM8(0xE0)
-
-/* RegDef:  CAN Status Interrupt MOb Register*/
 #define CANSIT1 _SFR_MEM8(0xE1)
 
 /* RegDef:  CAN Bit Timing Register 1*/
@@ -436,12 +439,16 @@
 #define CANCDMOB _SFR_MEM8(0xEF)
 
 /* RegDef:  CAN Identifier Tag Registers*/
+#define CANIDT  _SFR_MEM32(0xF0)
+
 #define CANIDT4 _SFR_MEM8(0xF0)
 #define CANIDT3 _SFR_MEM8(0xF1)
 #define CANIDT2 _SFR_MEM8(0xF2)
 #define CANIDT1 _SFR_MEM8(0xF3)
 
 /* RegDef:  CAN Identifier Mask Registers */
+#define CANIDM  _SFR_MEM32(0xF4)
+
 #define CANIDM4 _SFR_MEM8(0xF4)
 #define CANIDM3 _SFR_MEM8(0xF5)
 #define CANIDM2 _SFR_MEM8(0xF6)
@@ -601,7 +608,6 @@
 #define SPM_READY_vect			_VECTOR(36)
 #define SIG_SPM_READY			_VECTOR(36)
 
-
 #define _VECTORS_SIZE 148
 
 /* The Register Bit names are represented by their bit number (0-7). */
@@ -1400,7 +1406,7 @@
 /* MCU Control Register */
 #define    JTD     7
 #define    PUD     4
-#define    IVSE    1
+#define    IVSEL   1
 #define    IVCE    0
 /* End Register Bits */
 
