@@ -1,4 +1,4 @@
-/* Copyright (c) 2004,2005 Bob Paddock
+/* Copyright (c) 2004, 2005, 2006 Bob Paddock
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotn2313.h,v 1.9.2.1 2006/01/22 10:43:21 aesok Exp $ */
+/* $Id: iotn2313.h,v 1.9.2.4 2007/01/22 23:27:45 joerg_wunsch Exp $ */
 
 /* iotn2313.h derived from io2313.h by Bob Paddock.
 
@@ -453,7 +453,9 @@
 #define RFLB    3
 #define PGWRT   2
 #define PGERS   1
-#define SELFPRGE 0
+#define SPMEN   0   /* The name is used in ATtiny2313.xml file. */
+#define SELFPRGEN 0 /* The name is used in datasheet. */
+#define SELFPRGE  0 /* The name is left for compatibility. */
 
 /* ATtiny Timer/Counter Interrupt Flag register TIFR */
 #define TIFR    _SFR_IO8(0x38)
