@@ -1,5 +1,5 @@
 /* Copyright (c) 2002, 2004 Marek Michalkiewicz
-   Copyright (c) 2005 Eric B. Weddington
+   Copyright (c) 2005, 2006, 2007 Eric B. Weddington
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -29,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: wdt.h,v 1.22.2.1 2005/12/16 21:26:26 aesok Exp $ */
+/* $Id: wdt.h,v 1.22.2.14 2007/05/13 20:36:04 aesok Exp $ */
 
 /*
    avr/wdt.h - macros for AVR watchdog timer
@@ -41,6 +41,7 @@
 #include <avr/io.h>
 #include <stdint.h>
 
+/** \file */
 /** \defgroup avr_watchdog <avr/wdt.h>: Watchdog timer handling
     \code #include <avr/wdt.h> \endcode
 
@@ -115,18 +116,30 @@
 #endif
 
 
-#if defined (__AVR_ATmega169__) || defined(__AVR_AT90CAN128__) \
+#if defined(__AVR_AT90CAN128__) \
 || defined(__AVR_AT90CAN32__) || defined(__AVR_AT90CAN64__) \
+|| defined(__AVR_AT90USB82__) || defined(__AVR_AT90USB162__) \
+|| defined(__AVR_AT90USB646__) || defined(__AVR_AT90USB647__) \
+|| defined(__AVR_AT90USB1286__) || defined(__AVR_AT90USB1287__) \
 || defined(__AVR_ATmega48__) || defined(__AVR_ATmega88__) \
-|| defined(__AVR_ATmega164__) \
-|| defined(__AVR_ATmega165__) || defined(__AVR_ATmega168__) \
-|| defined(__AVR_ATmeg324__) \
+|| defined(__AVR_ATmega164P__) \
+|| defined(__AVR_ATmega165__) || defined(__AVR_ATmega165P__) \
+|| defined(__AVR_ATmega168__) \
+|| defined(__AVR_ATmega169__) || defined(__AVR_ATmega169P__) \
+|| defined(__AVR_ATmega324P__) \
 || defined(__AVR_ATmega325__) || defined(__AVR_ATmega3250__) \
 || defined(__AVR_ATmega329__) || defined(__AVR_ATmega3290__) \
-|| defined(__AVR_ATmega640__) || defined(__AVR_ATmega644__) \
+|| defined(__AVR_ATmega325P__) || defined(__AVR_ATmega3250P__) \
+|| defined(__AVR_ATmega329P__) || defined(__AVR_ATmega3290P__) \
+|| defined(__AVR_ATmega406__) \
+|| defined(__AVR_ATmega640__) \
+|| defined(__AVR_ATmega644__) || defined(__AVR_ATmega644P__) \
 || defined(__AVR_ATmega645__) || defined(__AVR_ATmega6450__) \
 || defined(__AVR_ATmega649__) || defined(__AVR_ATmega6490__) \
 || defined(__AVR_ATmega1280__) || defined(__AVR_ATmega1281__) \
+|| defined(__AVR_ATmega2560__) || defined(__AVR_ATmega2561__) \
+|| defined(__AVR_ATmega8HVA__) || defined(__AVR_ATmega16HVA__) \
+|| defined(__AVR_AT90PWM1__) \
 || defined(__AVR_AT90PWM2__) || defined(__AVR_AT90PWM3__)
  
 #define _wdt_write(value)   \
@@ -268,31 +281,37 @@ __asm__ __volatile__ (  \
 
 /** \ingroup avr_watchdog
     See \c WDT0_15MS
-    Note: This is only available on the ATtiny2313, 
+    Note: This is only available on the 
+    ATtiny2313, 
     ATtiny24, ATtiny44, ATtiny84, 
     ATtiny25, ATtiny45, ATtiny85, 
-    ATmega48, ATmega88,
-    ATmega164,
-    ATmega168,
-    ATmega324,
-    ATmega644,
-    ATmega640, ATmega1280, ATmega1281,
-    AT90PWM2, and the AT90PWM3.
+    ATtiny261, ATtiny461, ATtiny861, 
+    ATmega48, ATmega88, ATmega168,
+    ATmega164P, ATmega324P, ATmega644P, ATmega644,
+    ATmega640, ATmega1280, ATmega1281, ATmega2560, ATmega2561,
+    ATmega8HVA, ATmega16HVA,
+    ATmega406,
+    AT90PWM1, AT90PWM2, AT90PWM3,
+    AT90USB82, AT90USB162,
+    AT90USB646, AT90USB647, AT90USB1286, AT90USB1287.
     */
 #define WDTO_4S     8
 
 /** \ingroup avr_watchdog
     See \c WDT0_15MS
-    Note: This is only available on the ATtiny2313, 
+    Note: This is only available on the 
+    ATtiny2313, 
     ATtiny24, ATtiny44, ATtiny84, 
     ATtiny25, ATtiny45, ATtiny85, 
-    ATmega48, ATmega88,
-    ATmega164,
-    ATmega168,
-    ATmega324,
-    ATmega644,
-    ATmega640, ATmega1280, ATmega1281,
-    AT90PWM2, and the AT90PWM3.
+    ATtiny261, ATtiny461, ATtiny861, 
+    ATmega48, ATmega88, ATmega168,
+    ATmega164P, ATmega324P, ATmega644P, ATmega644,
+    ATmega640, ATmega1280, ATmega1281, ATmega2560, ATmega2561,
+    ATmega8HVA, ATmega16HVA,
+    ATmega406,
+    AT90PWM1, AT90PWM2, AT90PWM3,
+    AT90USB82, AT90USB162,
+    AT90USB646, AT90USB647, AT90USB1286, AT90USB1287.
     */
 #define WDTO_8S     9
 
