@@ -1,4 +1,4 @@
-/* Copyright (c) 2004,2005 Joerg Wunsch
+/* Copyright (c) 2004,2005,2007 Joerg Wunsch
    Copyright (c) 2005, Carlos Lamas
    All rights reserved.
 
@@ -29,13 +29,14 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: inttypes.h,v 1.14 2005/09/07 21:50:53 joerg_wunsch Exp $ */
+/* $Id: inttypes.h,v 1.14.2.2 2007/01/23 15:34:58 joerg_wunsch Exp $ */
 
 #ifndef __INTTYPES_H_
 #define __INTTYPES_H_
 
 #include <stdint.h>
 
+/** \file */
 /** \defgroup avr_inttypes <inttypes.h>: Integer Type conversions
     \code #include <inttypes.h> \endcode
 
@@ -299,7 +300,7 @@ typedef uint32_t uint_farptr_t;
 #define		PRIXFAST32		"lX"
 
 
-#if __avr_libc_does_not_implement_long_long_in_printf_or_scanf
+#ifdef __avr_libc_does_not_implement_long_long_in_printf_or_scanf
 
 #define		PRIo64			"llo"
 #define		PRIoLEAST64		"llo"
@@ -338,7 +339,7 @@ typedef uint32_t uint_farptr_t;
 #define		PRIXPTR			PRIX16
 
 
-#if __avr_libc_does_not_implement_hh_in_scanf
+#ifdef __avr_libc_does_not_implement_hh_in_scanf
 
 #define		SCNd8			"hhd"
 #define		SCNdLEAST8		"hhd"
@@ -393,7 +394,7 @@ typedef uint32_t uint_farptr_t;
 #define		SCNiFAST32		"li"
 
 
-#if __avr_libc_does_not_implement_long_long_in_printf_or_scanf
+#ifdef __avr_libc_does_not_implement_long_long_in_printf_or_scanf
 
 #define		SCNd64			"lld"
 #define		SCNdLEAST64		"lld"
@@ -415,7 +416,7 @@ typedef uint32_t uint_farptr_t;
     generic-integer scanf format for intptr_t */
 #define		SCNiPTR			SCNi16
 
-#if __avr_libc_does_not_implement_hh_in_scanf
+#ifdef __avr_libc_does_not_implement_hh_in_scanf
 
 #define		SCNo8			"hho"
 #define		SCNoLEAST8		"hho"
@@ -493,7 +494,7 @@ typedef uint32_t uint_farptr_t;
 #define		SCNxFAST32		"lx"
 
 
-#if __avr_libc_does_not_implement_long_long_in_printf_or_scanf
+#ifdef __avr_libc_does_not_implement_long_long_in_printf_or_scanf
 
 #define		SCNo64			"llo"
 #define		SCNoLEAST64		"llo"
