@@ -1,4 +1,4 @@
-/* Copyright (c) 2002, 2005, Joerg Wunsch
+/* Copyright (c) 2002, 2005, 2007 Joerg Wunsch
    All rights reserved.
 
    Portions of documentation Copyright (c) 1990, 1991, 1993
@@ -33,7 +33,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE.
 
-  $Id: stdio.h,v 1.24 2005/09/14 19:04:58 joerg_wunsch Exp $
+  $Id: stdio.h,v 1.24.2.3 2007/01/23 15:34:58 joerg_wunsch Exp $
 */
 
 #ifndef _STDIO_H_
@@ -48,6 +48,7 @@
 #define __need_size_t
 #include <stddef.h>
 
+/** \file */
 /** \defgroup avr_stdio <stdio.h>: Standard IO facilities
     \code #include <stdio.h> \endcode
 
@@ -139,16 +140,12 @@
     \anchor stdio_without_malloc
     <h3>Running stdio without malloc()</h3>
 
-    By default, fdevopen() as well as the floating-point versions of
-    the printf and scanf family require malloc().  As this is often
+    By default, fdevopen() requires malloc().  As this is often
     not desired in the limited environment of a microcontroller, an
     alternative option is provided to run completely without malloc().
 
     The macro fdev_setup_stream() is provided to prepare a
-    user-supplied FILE buffer for operation with stdio.  If
-    floating-point operation is desired, a user-supplied buffer can as
-    well be passed for the internal buffering for the floating-point
-    numbers (and processing of \%[ scanf data).
+    user-supplied FILE buffer for operation with stdio.
 
     <h4>Example</h4>
 
@@ -165,7 +162,7 @@
     {
 
       if (c == '\n')
-        uart_putchar('\r');
+        uart_putchar('\r', stream);
       loop_until_bit_is_set(UCSRA, UDRE);
       UDR = c;
       return 0;
@@ -975,11 +972,12 @@ extern int	ferror(FILE *__stream);
      By default, all the conversions described above are available
      except the floating-point conversions, and the <tt>\%[</tt> conversion.
      These conversions will be available in the extended version
-     provided by the library \c libscanf_flt.a.  Note that either of
-     these conversions requires the availability of a buffer that
-     needs to be obtained at run-time using malloc().  If this buffer
-     cannot be obtained, the operation is aborted, returning the
-     value \c EOF.  To link a program against the extended version,
+     provided by the library \c libscanf_flt.a.  Note that these
+     conversions require a 40-byte conversion buffer, so the
+     extended version requires more stack space than the basic
+     version irrespective of whether the actual call in progress
+     actually uses this buffer or not.
+     To link a program against the extended version,
      use the following compiler flags in the link stage:
 
      \code
